function [ex,ey,ez,hx,hy,hz] = Dipole_fields(x1,y1,z1,x2,y2,z2,er,f,X,Y,Z)
%
% Campi di un dipolo elettrico di momento I*l unitario orientato arbitrariamente.
% x1,y1,z1 (m) posizione dipolo (distanze calcolate rispetto a x1,y1,z1)
% x2,y2,z2 (m) posizione estremo finale del dipolo (serve solo per definire la
% direzione)
% er = epsilon relativa
% f = frequenza (Hz)
% X,Y,Z (m) punto di osservazione
%
% output: ex,ey,ez (V/m), hx,hy,hz (A/m)
% ATTENZIONE: convenzione exp(-i*omega*t)
% per passare all'altra convenzione basta scrivere ui = -i

ui = i;

v0 = 2.997925e8;
mu0 = pi*4e-7;
eps0 = 1/(v0^2*mu0);
eps = eps0*er;
mu = mu0*1;
omega = 2*pi*f;
k = omega*sqrt(mu*eps);
eta = sqrt(mu/eps);

L = sqrt((x2-x1).^2+(y2-y1).^2+(z2-z1).^2);
px = (x2-x1)/L;
py = (y2-y1)/L;
pz = (z2-z1)/L;
p = 1;

% versore ur
R = sqrt((X-x1).^2+(Y-y1).^2+(Z-z1).^2);
Rx = (X-x1); Ry = (Y-y1); Rz = (Z-z1);
urx = Rx./R; ury = Ry./R; urz = Rz./R;

% versore uphi
Uphix = (py.*Rz-pz.*Ry); 
Uphiy = -(px.*Rz-pz.*Rx);
Uphiz = (px.*Ry-py.*Rx);
Uphi = sqrt(Uphix.^2+Uphiy.^2+Uphiz.^2);
if Uphi<1e-19
    uphix = 0; uphiy = 0; uphiz = 0;
else
    uphix = Uphix./Uphi; uphiy = Uphiy./Uphi; uphiz = Uphiz./Uphi;
end
% versore utheta
uthx = uphiy.*urz-uphiz.*ury; 
uthy = -(uphix.*urz-uphiz.*urx);
uthz = uphix.*ury-uphiy.*urx;

costheta = (px.*Rx + py.*Ry + pz.*Rz)./(p.*R);
sintheta = sqrt(1 - costheta.^2);

ekr = exp(ui*k*R);
U = ui*p/(2*pi*f);
Er = (U/(2*pi*eps)).*(1./R.^3 - ui*k./R.^2).*costheta.*ekr;
Et = (U/(4*pi*eps)).*(1./R.^3 - ui*k./R.^2 - k^2./R).*sintheta.*ekr;
Hp = (U/(4*pi*eps*eta)).*(-ui*k./R.^2 - k^2./R).*sintheta.*ekr;

ex = Er.*urx + Et.*uthx;
ey = Er.*ury + Et.*uthy;
ez = Er.*urz + Et.*uthz;
hx = Hp.*uphix;
hy = Hp.*uphiy;
hz = Hp.*uphiz;
