clear
f = 800e6;            % freq Hz
PT = 8;               %transmitted power W
h = 0.8;              % height h with respect to ground (dipole TX at 0,0,h)
p1 = [-150 -100 350]; % [x y z] receiving point 
um0 = [0 1 0 ];       % direction of TX dipole
lsulambda = 0.1;      % length (over lambda) of TX and RX dipole.
irx = [1 0 0];        % direction of RX dipole (length equal to TX)

%--- start --------------------------------------------

lambda = 3e8/f;
l = lambda*lsulambda; % lunghezza dipolo trasmittente
Rrad = (2*pi/3)*377*(l/lambda)^2;
I0 = sqrt(2*PT/Rrad);
m0 = I0*l*um0/sqrt(um0*um0'); % momento dipolo trasm.
m0_image = m0.*[-1 -1 1];

p01 = [0 0 h]; % punto dipolo trasmittente
p02 = [0 0 -h]; % punto secondo dipolo (immagine)

[E1,H1] = Dipole_fields_new(m0,p01,p1,f); % campi sul dipolo ricevente
[E2,H2] = Dipole_fields_new(m0_image,p02,p1,f); % campi sul dipolo ricevente
E = E1+E2; H = H1+H2;

Lrx = l*irx/sqrt(irx*irx');

V0 = abs(E*Lrx');
PRX = abs(V0)^2/(8*Rrad);


k = 2*pi/lambda;
im0 = m0/sqrt(m0*m0');
im0_image = m0_image/sqrt(m0_image*m0_image');
[ur,uphi,utheta,sintheta] = local_vectors(m0,p1);
GF = sum(abs(im0 + im0_image*exp(j*k*2*h*ur(3))));

% Display
disp('ESERCIZIO: link budget between two electric dipoles with ground')
disp(sprintf('freq (Hz) = %g ',f));
disp(sprintf('PT = %g W (power transmitted)',PT));
disp(sprintf('Point dipole TX1: %g, %g, %g ',p01(1),p01(2),p01(3)));
disp(sprintf('Point dipole TX2: %g, %g, %g (image)',p02(1),p02(2),p02(3)));
disp(sprintf('Length dipole TX1: %g m',l));
disp(sprintf('Current dipole TX1: %g A',I0));
disp(sprintf('Moment dipole TX1: %g, %g, %g A*m',m0(1),m0(2),m0(3)));
disp(sprintf('Point dipole RX: %g, %g, %g m',p1(1),p1(2),p1(3)));
disp(sprintf('Direction dipole RX: [%g %g %g]',irx));
disp(' ')
disp('*** Local vectors')
disp(sprintf('ur = [%g %g %g]',ur))
disp(sprintf('uphi = [%g %g %g]',uphi))
disp(sprintf('utheta = [%g %g %g]',utheta))
disp(sprintf('Theta = %g',asin(sintheta)*180/pi))
disp(' ')
disp(sprintf('E Field at RX dipole: %g, %g, %g [V/m] (mag components)',abs(E(1)),abs(E(2)),abs(E(3))));
disp(sprintf('H Field at RX dipole: %g, %g, %g [A/m] (mag components)',abs(H(1)),abs(H(2)),abs(H(3))));
disp(sprintf('Effective length RX dipole: %g, %g, %g [m]',Lrx(1),Lrx(2),Lrx(3)));
disp(sprintf('Open circuit voltage at RX: %g [V]',abs(V0)));
disp(sprintf('Power received: %g [W]',PRX));
disp(sprintf('(Group factor = %g)',GF));


%--- functions

